#include "../src/ui/ui.h"
#include "../src/utils/macros.h"

void
vifm_restart(void)
{
	/* Do nothing. */
}

void
vifm_try_leave(int write_info, int cquit, int force)
{
	/* Do nothing. */
}

void
vifm_choose_files(const FileView *view, int nfiles, char *files[])
{
	/* Do nothing. */
}

void
vifm_finish(const FileView *view, int nfiles, char *files[])
{
	/* Do nothing. */
}

/* vim: set tabstop=2 softtabstop=2 shiftwidth=2 noexpandtab cinoptions-=(0 : */
/* vim: set cinoptions+=t0 : */
